Natural Evolution Strategies (NES)
==================================

.. autoclass:: pypop7.optimizers.nes.nes.NES



.. toctree::
   :maxdepth: 1
   :caption: NES:

   r1nes
   snes
   xnes
   enes
   ones
   sges
